@@ -7,14 +7,16 @@ use strict;
 use warnings;
 
 use lib qw(../lib);
-use Math::AnyNum qw(:overload float);
+use Math::AnyNum qw(:overload float approx_cmp);
 
 sub derivatives {
     my ($x, $m, $k) = @_;
+
     my $fx   = $x**$m - $k;
     my $dfx  = ($m * $x**($m - 1));
     my $ddfx = (($m - 1) * $m) * $x**($m - 2);
-    ($fx, $dfx, $ddfx);
+
+    return ($fx, $dfx, $ddfx);
 }
 
 sub halleys_method {
@@ -24,11 +26,10 @@ sub halleys_method {
     my $m = float($m0);
     my $k = float($k0);
 
-    my @fx  = derivatives($x, $m, $k);
-    my $eps = 10**-($Math::AnyNum::PREC >> 2);
-    my $r   = $fx[0] / ($fx[1] - ($fx[0] * $fx[2]) / (2 * $fx[1]));
+    my @fx = derivatives($x, $m, $k);
+    my $r = $fx[0] / ($fx[1] - ($fx[0] * $fx[2]) / (2 * $fx[1]));
 
-    while (abs($fx[0]) > $eps) {
+    until (approx_cmp($fx[0], 0) == 0) {
         $r = ($fx[0] / ($fx[1] - (($fx[0] * $fx[2]) / (2 * $fx[1]))));
         $x -= $r;
         @fx = derivatives($x, $m, $k);
@@ -44,6 +45,9 @@ say halleys_method(1, 7,  42**7);
 say halleys_method(1, 42, 987**42);
 
 # Complex roots
-say halleys_method(sqrt(-1), 2,  -1);
-say halleys_method(sqrt(-1), 2,  -2);
-say halleys_method(sqrt(-1), -3, -4);
+say halleys_method(sqrt(-1), 2,      -1);
+say halleys_method(sqrt(-1), 2,      -2);
+say halleys_method(sqrt(-1), -3,     -4);
+say halleys_method(sqrt(-1), -3 * i, -4);
+say halleys_method(sqrt(-1), -3,     -4 * i);
+say halleys_method(sqrt(-1), -3 * i, -4 * i);
